import { ChatMessageResult, EmployeeSearchResult } from "@/utils/clientsApis";

/**
 * 聊天记录
 * 
 * @interface ChatMessage
 * @property {string} id - 消息ID
 * @property {string} role - 角色 user-用户 assistant-助手
 * @property {string} content - 内容
 * @property {model} role - 模型
 * @property {number} createAt - 创建时间
 * @property {number} updateAt - 更新时间
 */
export interface ChatMessage {
    id: string;
    role: string;//user  assistant
    content: string;
    parentId: string;
    model: string;
    createAt: number;
    updateAt: number;
}

export function MessageChange(list: ChatMessageResult[]) {
    const chatMessageList: ChatMessage[] = [];
    list.forEach((item) => {
        if (item.query) {
            chatMessageList.push({
                id: item.id,
                role: 'user',
                parentId: '',
                model: '',
                content: item.query,
                createAt: item.createdAt,
                updateAt: item.createdAt
            })
        }
        if (item.answer) {
            chatMessageList.push({
                id: item.id + '_assistant',
                role: 'assistant',
                parentId: item.id,
                model: '',
                content: item.answer,
                createAt: item.createdAt,
                updateAt: item.createdAt
            })
        }
    })
    return chatMessageList
}

const STORAGE_KEY_CHAT_MODEL_LIST = 'chat-model-list';
/**
 * 本地存储 - 助手列表
 * 
 * @interface ChatAiModel
 * @property {number} id - ID
 * @property {string} name - 名称
 * @property {string} avatar - 头像
 * @property {string} estimate - 描述
 * @property {string} ConversationId - 会话ID
 * @property {number} createdAt - 创建时间（时间戳）
 */
export interface ChatAiModel {
    id: number;
    name: string;
    avatar: string;
    estimate: string;
    createdAt: number;
    ConversationId: string;
}

export function SetChatModelListForLocalStorage(list: ChatAiModel[]) {
    localStorage.setItem(STORAGE_KEY_CHAT_MODEL_LIST, JSON.stringify(list));
}

export const GetChatModelListForLocalStorage=(): ChatAiModel[] =>  {
    let list = JSON.parse(localStorage.getItem(STORAGE_KEY_CHAT_MODEL_LIST) || '[]')as ChatAiModel[];
    return list
}

export const LoadLocalChatList = (model: EmployeeSearchResult): ChatAiModel[] => {
    var list = GetChatModelListForLocalStorage();
    if (list === null) {
        list = [
            {
                id: model.id,
                name: model.title,
                avatar: model.avatar,
                estimate: model.estimate,
                createdAt: model.createdAt,
                ConversationId: "",
            },
        ];
    } else {
        var index = list.findIndex((v) => v.id == model.id);
        if (index < 0) {
            list = [
                ...[
                    {
                        id: model.id,
                        name: model.title,
                        avatar: model.avatar,
                        estimate: model.estimate,
                        createdAt: model.createdAt,
                        ConversationId: "",
                    },
                ],
                ...list,
            ];
        }
    }
    SetChatModelListForLocalStorage(list);
    return list;
}

export const UpdateLocalChatListForConversationId = (id:number,conversationId:string): ChatAiModel[] => {
    var list = GetChatModelListForLocalStorage();
    if (list !== null) {
        var index = list.findIndex((v) => v.id == id);
        if (index >= 0 && (list[index].ConversationId == '' || list[index].ConversationId.includes("guid_0000_"))) {
            list[index].ConversationId = conversationId;
        }
    } 
    SetChatModelListForLocalStorage(list);
    return list;
}

export const GetLocalChatModelDetails = (id:number): ChatAiModel => {
    var list = GetChatModelListForLocalStorage();
    if (list !== null) {
        var index = list.findIndex((v) => v.id == id);
        if (index >= 0 ) {
            return  list[index];
        }
    } 
    return {id:0,name:"",avatar:"",estimate:"",createdAt:0,ConversationId:"" };
}

const STORAGE_KEY_CHAT_LAST_USED = 'chat-last-used';
/**
 * 本地存储 - 上次使用助手设置
 * 
 * @interface ChatLastUsed
 * @property {number} listType - 助手列表类型 0历史列表 1助手列表
 * @property {number} agentId - 智能体ID
 * @property {string} ConversationId - 会话ID
 */
export interface ChatLastUsed {
    listType: number;
    agentId: number;
    conversationId: string;
}
export const DEFAULT_CHATLASTUSED = {
    listType: 0,
    agentId: 0,
    conversationId: '',
};

export const SetChatLastUsedForLocalStorage = (value: ChatLastUsed) => {
    localStorage.setItem(STORAGE_KEY_CHAT_LAST_USED, JSON.stringify(value));
}

export const GetChatLastUsedForLocalStorage = (): ChatLastUsed => {
    let model = DEFAULT_CHATLASTUSED;
    if (typeof localStorage === 'undefined') return model;
    const modelJson = localStorage.getItem(STORAGE_KEY_CHAT_LAST_USED);
    if (modelJson) {
        let savedModel = JSON.parse(modelJson) as ChatLastUsed;
        model = Object.assign(model, savedModel);
    }
    return model;
}





